@@ -1,9 +1,5 @@
 library(bayesnec)
 
-data(manec_example)
-ecx4param <- pull_out(manec_example, model = "ecx4param")
-nec4param <- pull_out(manec_example, model = "nec4param")
-
 test_that("input errors work as intended", {
   expect_error(compare_posterior(list(ecx4param, nec4param)),
                "Argument x must be a named list.")
